// Copyright 2023 QMK
// SPDX-License-Identifier: GPL-2.0-or-later

#include QMK_KEYBOARD_H

const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
    /*
     * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┐
     * │ESC│ Q │ W │ E │ R │ T │ Y │ U │ I │ O │ P │BCK│
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │TAB│ A │ S │ D │ F │ G │ H │ J │ K │ L │ ; │ @ │
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │SFT│ Z │ X │ C │ V │ B │ N │ M │ , │ . │ / │ENT│
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │CTL│WIN│ALT│DEL│MO1│  SPC  │TG1│LFT│DWN│UP │RGT│
     * └───┴───┴───┴───┴───┴───┴───┴───┴───┴───┴───┴───┘
     */
	[0] = LAYOUT_ortho_4x12(
	    KC_ESC,  KC_Q,    KC_W,    KC_E,    KC_R,    KC_T,    KC_Y,    KC_U,    KC_I,    KC_O,    KC_P,    KC_BSPC,
        KC_TAB,  KC_A,    KC_S,    KC_D,    KC_F,    KC_G,    KC_H,    KC_J,    KC_K,    KC_L,    KC_SCLN, KC_QUOT,
        KC_LSFT, KC_Z,    KC_X,    KC_C,    KC_V,    KC_B,    KC_N,    KC_M,    KC_COMM, KC_DOT,  KC_SLSH, KC_ENT,
		KC_LCTL, KC_LGUI, KC_LALT, KC_DEL,  MO(1),   KC_NO,   KC_SPC,  TG(1),   KC_LEFT, KC_DOWN, KC_UP,   KC_RGHT
    ),
	/*
     * ┌───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┬───┐
     * │ESC│ 1 │ 2 │ 3 │ 4 │ 5 │ 6 │ 7 │ 8 │ 9 │ 0 │BCK│
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │ F1│ F2│ F3│ F4│ F5│ F6│ F7│ F8│ F9│F10│F11│F12│
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │SFT│PGU│PGD│ V-│ V+│ - │ = │ \ │ # │ [ │ ] │ENT│
     * ├───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┼───┤
     * │CTL│WIN│ALT│DEL│   │  SPC  │TG0│LFT│DWN│UP │RGT│
     * └───┴───┴───┴───┴───┴───┴───┴───┴───┴───┴───┴───┘
     */
	[1] = LAYOUT_ortho_4x12(
	    KC_ESC,  KC_1,    KC_2,   KC_3,   KC_4,    KC_5,    KC_6,    KC_7,    KC_8,    KC_9,    KC_0,    KC_BSPC,
	    KC_F1,   KC_F2,   KC_F3,  KC_F4,  KC_F5,   KC_F6,   KC_F7,   KC_F8,   KC_F9,   KC_F10,  KC_F11,  KC_F12,
        KC_LSFT, KC_PGUP, KC_PGDN,KC_VOLD,KC_VOLU, KC_MINS, KC_EQL,  KC_NUBS, KC_NUHS, KC_LBRC, KC_RBRC, KC_ENT,
        KC_LCTL, KC_LGUI, KC_LALT,KC_DEL, KC_TRNS, KC_NO,   KC_SPC,  KC_TRNS, KC_LEFT, KC_DOWN, KC_UP,   KC_RGHT
    )
};

// Light LEDs 9 & 10 in cyan when keyboard layer 0 is active
const rgblight_segment_t PROGMEM my_layer0_layer[] = RGBLIGHT_LAYER_SEGMENTS(
    {0, 3, HSV_CYAN}
);

// Light LEDs 11 & 12 in purple when keyboard layer 1 is active
const rgblight_segment_t PROGMEM my_layer1_layer[] = RGBLIGHT_LAYER_SEGMENTS(
    {0, 3, HSV_PURPLE}
);

// Now define the array of layers. Later layers take precedence
const rgblight_segment_t* const PROGMEM my_rgb_layers[] = RGBLIGHT_LAYERS_LIST(
    my_layer0_layer,    // Overrides caps lock layer
    my_layer1_layer    // Overrides other layers
);

void keyboard_post_init_user(void) {
    // Enable the LED layers
    rgblight_layers = my_rgb_layers;
}

layer_state_t default_layer_state_set_user(layer_state_t state) {
    rgblight_set_layer_state(0, layer_state_cmp(state, 0));
    return state;
}

layer_state_t layer_state_set_user(layer_state_t state) {
    rgblight_set_layer_state(1, layer_state_cmp(state, 1));
    return state;
}